@@ -19,7 +19,7 @@ from sunpy.coordinates import frames
 data = np.arange(0, 100).reshape(10, 10)
 
 ##############################################################################
-# Next we need to create the metadata. This is made easier using the `~sunpy.map.header_helper`
+# Next we need to create the metadata. This is made easier using the `~sunpy.map.make_fitswcs_header`
 # function which will create a header object for you. First define the reference coordinate
 # which requires a time and an observer location.
 coord = SkyCoord(0*u.arcsec, 0*u.arcsec, obstime='2013-10-28 08:24',
@@ -30,11 +30,11 @@ coord = SkyCoord(0*u.arcsec, 0*u.arcsec, obstime='2013-10-28 08:24',
 # The reference pixel is the pixel is the one at the reference coordinate. The
 # scale sets the size of the pixels. You can also to set a number of other
 # metadata as well such as the instrument name and wavelength.
-header = sunpy.map.header_helper.make_fitswcs_header(data, coord,
-                                                     reference_pixel=[0, 0]*u.pixel,
-                                                     scale=[2, 2]*u.arcsec/u.pixel,
-                                                     telescope='Fake Telescope', instrument='UV detector',
-                                                     wavelength=1000*u.angstrom)
+header = sunpy.map.make_fitswcs_header(data, coord,
+                                       reference_pixel=[0, 0]*u.pixel,
+                                       scale=[2, 2]*u.arcsec/u.pixel,
+                                       telescope='Fake Telescope', instrument='UV detector',
+                                       wavelength=1000*u.angstrom)
 
 ##############################################################################
 # Let's now create our map.
