@@ -1,6 +1,6 @@
 
 import pytest
-from hypothesis import given, settings
+from hypothesis import HealthCheck, given, settings
 
 import astropy.units as u
 from astropy.constants import c as speed_of_light
@@ -12,15 +12,6 @@ from sunpy.coordinates.ephemeris import get_body_heliographic_stonyhurst, get_ea
 from .strategies import times
 
 
-@pytest.fixture(scope='function')
-def astropy_ephemeris_de432s():
-    # Temporarily set Astropy's ephemeris to DE432s
-    old_ephemeris = solar_system_ephemeris.get()
-    solar_system_ephemeris.set('de432s')
-    yield solar_system_ephemeris.get()
-    solar_system_ephemeris.set(old_ephemeris)
-
-
 def test_get_body_heliographic_stonyhurst():
     # Validate against published values from the Astronomical Almanac (2013)
     e1 = get_body_heliographic_stonyhurst('earth', '2013-Jan-01')
@@ -124,12 +115,28 @@ def test_get_horizons_coord_array_time():
     assert_quantity_allclose(e[3].radius, 0.9908173*u.AU, atol=5e-7*u.AU)
 
 
+@pytest.fixture
+def use_DE440s():
+    # This class is for test functions that need the Astropy ephemeris to be set to DE432s
+    pytest.importorskip("astroquery")
+
+    old_ephemeris = solar_system_ephemeris.get()
+    try:
+        solar_system_ephemeris.set('de440s')
+    except ValueError:
+        pytest.skip("The installed version of Astropy cannot set the ephemeris to DE440s")
+
+    yield
+
+    solar_system_ephemeris.set(old_ephemeris)
+
+
 @pytest.mark.remote_data
 @given(obstime=times())
-@settings(deadline=5000, max_examples=10)
-def test_consistency_with_horizons(astropy_ephemeris_de432s, obstime):
-    # get_horizons_coord() depends on astroquery
-    pytest.importorskip("astroquery")
+@settings(deadline=5000, max_examples=10, suppress_health_check=[HealthCheck.function_scoped_fixture])
+def test_consistency_with_horizons(use_DE440s, obstime):
+    # Check that the high-accuracy Astropy ephemeris has been set
+    assert solar_system_ephemeris.get() == 'de440s'
 
     # Check whether the location of Earth is the same between Astropy and JPL HORIZONS
     e1 = get_earth(obstime)
