@@ -108,7 +108,8 @@ def get_goes_event_list(timerange, goes_class_filter=None):
     `list`:
         A list of all the flares found for the given time range.
     """
-    # Importing hek here to avoid calling code that relies on optional dependencies.
+    # Importing hek and attrs here to avoid calling code that relies on optional dependencies.
+    from sunpy.net import attrs as a
     from sunpy.net import hek
 
     # use HEK module to search for GOES events
@@ -120,14 +121,14 @@ def get_goes_event_list(timerange, goes_class_filter=None):
     # query the HEK for a list of events detected by the GOES instrument
     # between tstart and tend (using a GOES-class filter)
     if goes_class_filter:
-        result = client.search(hek.attrs.Time(tstart, tend),
-                               hek.attrs.EventType(event_type),
-                               hek.attrs.FL.GOESCls > goes_class_filter,
-                               hek.attrs.OBS.Observatory == 'GOES')
+        result = client.search(a.Time(tstart, tend),
+                               a.hek.EventType(event_type),
+                               a.hek.FL.GOESCls > goes_class_filter,
+                               a.hek.OBS.Observatory == 'GOES')
     else:
-        result = client.search(hek.attrs.Time(tstart, tend),
-                               hek.attrs.EventType(event_type),
-                               hek.attrs.OBS.Observatory == 'GOES')
+        result = client.search(a.Time(tstart, tend),
+                               a.hek.EventType(event_type),
+                               a.hek.OBS.Observatory == 'GOES')
 
     # want to condense the results of the query into a more manageable
     # dictionary
@@ -672,7 +673,9 @@ def _goes_get_chianti_em(longflux: u.W/u.m/u.m, temp: u.MK, satellite=8,
     # Check inputs are of correct type
     longflux = longflux.to(u.W/u.m**2)
     temp = temp.to(u.MK)
-    log10_temp = np.log10(temp.value)
+    # Ignore zero values raising a numpy warning here
+    with np.errstate(invalid='ignore'):
+        log10_temp = np.log10(temp.value)
     int(satellite)
     if satellite < 1:
         raise ValueError("satellite must be the number of a "
