@@ -1,4 +1,3 @@
-
 import numpy as np
 
 import astropy.units as u
@@ -6,9 +5,10 @@ import astropy.wcs
 from astropy.coordinates import SkyCoord
 
 from sunpy.coordinates import frames, sun
+from sunpy.sun.constants import radius as _RSUN
 from sunpy.util import MetaDict
 
-__all__ = ['meta_keywords', 'make_fitswcs_header']
+__all__ = ['meta_keywords', 'make_fitswcs_header', 'get_observer_meta']
 
 
 def meta_keywords():
@@ -161,6 +161,15 @@ def make_fitswcs_header(data, coordinate,
          meta_wcs['PC2_1'], meta_wcs['PC2_2']) = (rotation_matrix[0, 0], rotation_matrix[0, 1],
                                                   rotation_matrix[1, 0], rotation_matrix[1, 1])
 
+    if getattr(coordinate, 'observer', None) is not None:
+        # Have to check for str, as doing == on a SkyCoord and str raises an error
+        if isinstance(coordinate.observer, str) and coordinate.observer == 'self':
+            dsun_obs = coordinate.radius
+        else:
+            dsun_obs = coordinate.observer.radius
+        rsun = getattr(coordinate, 'rsun', _RSUN)
+        meta_wcs['rsun_obs'] = sun._angular_radius(rsun, dsun_obs).to_value(u.arcsec)
+
     meta_dict = MetaDict(meta_wcs)
 
     return meta_dict
@@ -182,6 +191,7 @@ def _get_wcs_meta(coordinate, projection_code):
             * ctype1, ctype2
             * cunit1, cunit2
             * date_obs
+            * observer auxillary information, if set on `coordinate`
     """
 
     coord_meta = {}
