@@ -3,6 +3,7 @@ Map is a generic Map class from which all other Map classes inherit from.
 """
 import copy
 import html
+import numbers
 import textwrap
 import warnings
 import webbrowser
@@ -505,6 +506,8 @@ class GenericMap(NDData):
         w2.wcs.crval = u.Quantity([self._reference_longitude, self._reference_latitude])
         w2.wcs.ctype = self.coordinate_system
         w2.wcs.pc = self.rotation_matrix
+        # FITS standard doesn't allow both PC_ij *and* CROTA keywords
+        w2.wcs.crota = (0, 0)
         w2.wcs.cunit = self.spatial_units
         w2.wcs.dateobs = self.date.isot
         w2.wcs.aux.rsun_ref = self.rsun_meters.to_value(u.m)
@@ -892,8 +895,11 @@ class GenericMap(NDData):
         Notes
         -----
         This value is taken the ``'rsun_obs'``, ``'solar_r'``, or ``radius``
-        FITS keywords. If none of these keys are present the photospheric limb
-        as seen from the observer coordinate is returned.
+        FITS keywords. If none of these keys are present, the angular radius
+        will be calculated from the radius of the Sun (taken from the
+        ``rsun_ref`` FITS keyword) and the observer distance.  If the
+        ``rsun_ref`` key is not present, the standard radius of the photosphere
+        will be assumed.
         """
         rsun_arcseconds = self.meta.get('rsun_obs',
                                         self.meta.get('solar_r',
@@ -901,11 +907,11 @@ class GenericMap(NDData):
                                                                     None)))
 
         if rsun_arcseconds is None:
-            warnings.warn("Missing metadata for solar angular radius: assuming photospheric limb "
-                          "as seen from observer coordinate.",
-                          SunpyUserWarning)
-            dsun = self.dsun
-            rsun = sun._angular_radius(constants.radius, dsun)
+            if 'rsun_ref' not in self.meta:
+                warnings.warn("Missing metadata for solar angular radius: assuming the standard "
+                              "radius of the photosphere as seen from the observer distance.",
+                              SunpyUserWarning)
+            rsun = sun._angular_radius(self.rsun_meters, self.dsun)
         else:
             rsun = rsun_arcseconds * u.arcsec
         return rsun
@@ -1461,6 +1467,12 @@ class GenericMap(NDData):
         pad_x = int(np.max((diff[1], 0)))
         pad_y = int(np.max((diff[0], 0)))
 
+        if issubclass(self.data.dtype.type, numbers.Integral) and (missing % 1 != 0):
+            warnings.warn(
+                "The specified `missing` value is not an integer, but the data "
+                "array is of integer type, so the output may be strange.",
+                SunpyUserWarning)
+
         new_data = np.pad(self.data,
                           ((pad_y, pad_y), (pad_x, pad_x)),
                           mode='constant',
@@ -1956,7 +1968,7 @@ class GenericMap(NDData):
         c_kw.update(kwargs)
 
         circ = patches.Circle([0, 0], **c_kw)
-        axes.add_patch(circ)
+        axes.add_artist(circ)
 
         return [circ]
 
