@@ -173,13 +173,19 @@ def test_rsun_meters(generic_map):
     assert generic_map.rsun_meters == sunpy.sun.constants.radius
 
 
-def test_rsun_obs(generic_map):
+def test_rsun_obs_without_rsun_ref(generic_map):
     with pytest.warns(SunpyUserWarning,
-                      match='Missing metadata for solar angular radius: assuming '
-                      'photospheric limb as seen from observer coordinate.'):
+                      match='assuming the standard radius of the photosphere '
+                            'as seen from the observer distance'):
         assert_quantity_allclose(generic_map.rsun_obs, sun.angular_radius(generic_map.date))
 
 
+def test_rsun_obs_with_rsun_ref(generic_map):
+    generic_map.meta['rsun_ref'] = sunpy.sun.constants.radius
+    # The following should not raise a warning because we can calculate it exactly
+    assert_quantity_allclose(generic_map.rsun_obs, sun.angular_radius(generic_map.date))
+
+
 def test_coordinate_system(generic_map):
     assert generic_map.coordinate_system == ('HPLN-TAN', 'HPLT-TAN')
 
