@@ -56,21 +56,16 @@ def test_fetch_working(indices_client, tmpdir):
     """
     qr1 = indices_client.search(Time('2012/10/4', '2012/10/6'),
                                 Instrument('noaa-indices'))
-
     # Mock QueryResponse object
     mock_qr = mock_query_object('2012/10/4', '2012/10/6')
-
     # Compare if two objects have the same attribute
-
     mock_qr = mock_qr[0]
     qr = qr1[0]
-
     assert mock_qr['Source'] == qr['Source']
     assert mock_qr['Provider'] == qr['Provider']
     assert mock_qr['Physobs'] == qr['Physobs']
     assert mock_qr['Instrument'] == qr['Instrument']
     assert mock_qr['url'] == qr['url']
-
     target_dir = tmpdir.mkdir("down")
     download_list = indices_client.fetch(qr1, path=target_dir)
     assert len(download_list) == len(qr1)
@@ -178,24 +173,15 @@ def test_srs_tar_unpack_midyear():
     assert res.data[-1].endswith("20110608SRS.txt")
 
 
-@no_vso
-@pytest.mark.remote_data
-@mock.patch('ftplib.FTP.nlst', side_effect=[[''], ['20200101SRS.txt', '20200102SRS.txt']])
-def test_srs_missing_tarball(mock_ftp_nlst):
-    qr = Fido.search(a.Time('2020-01-01', '2020-01-02'), a.Instrument.srs_table)
-    urls = [qrblock['url'] for qrblock in qr[0]]
-    assert urls[0].endswith('20200101SRS.txt')
-    assert urls[1].endswith('20200102SRS.txt')
-
-
 @no_vso
 @pytest.mark.remote_data
 def test_srs_current_year():
+    # Current year is nothing but text files, all older years should be tar files.
     year = datetime.date.today().year
-    qr = Fido.search(a.Instrument("soon") & a.Time(f"{year}/02/01", f"{year}/02/01T23:59:29"))
+    qr = Fido.search(a.Instrument("soon") & a.Time(f"{year}/01/01", f"{year}/01/01T23:59:29"))
     res = Fido.fetch(qr)
     assert len(res) == 1
-    assert res.data[0].endswith(f"{year}0201SRS.txt")
+    assert res.data[0].endswith(f"{year}0101SRS.txt")
 
 
 @no_vso
@@ -227,6 +213,14 @@ def test_srs_start_or_end_out_of_range(srs_client):
     assert len(res) > 0
 
 
+@pytest.mark.remote_data
+def test_tar_file_broken():
+    # 2010 extracts out to 2010_SRS while other years do SRS only.
+    results = Fido.search(a.Time("2010/5/1", "2010/5/2"), a.Instrument.soon)
+    results = Fido.fetch(results)
+    assert len(results) == 2
+
+
 def test_no_time(predict_client, indices_client):
     res = indices_client.search(a.Instrument.noaa_indices)
     assert len(res) == 1
