@@ -1,6 +1,7 @@
 import os
 import glob
 import datetime
+from pathlib import Path
 from collections import OrderedDict
 
 import numpy as np
@@ -18,6 +19,7 @@ import sunpy.timeseries
 from sunpy.time import parse_time
 from sunpy.util import SunpyUserWarning
 from sunpy.util.datatype_factory_base import NoMatchError
+from sunpy.util.exceptions import SunpyDeprecationWarning
 from sunpy.util.metadata import MetaDict
 
 # =============================================================================
@@ -37,6 +39,8 @@ noaa_ind_txt_filepath = os.path.join(filepath, 'RecentIndices_truncated.txt')
 noaa_pre_txt_filepath = os.path.join(filepath, 'predicted-sunspot-radio-flux_truncated.txt')
 goes_filepath_com = os.path.join(filepath, 'go1520120601.fits.gz')
 goes_filepath = os.path.join(filepath, 'go1520110607.fits')
+new_goes15_filepath = os.path.join(filepath, 'goes_truncated_test_goes15.nc')
+new_goes16_filepath = os.path.join(filepath, 'goes_truncated_test_goes16.nc')
 a_list_of_many = glob.glob(os.path.join(filepath, "eve", "*"))
 
 # =============================================================================
@@ -45,6 +49,7 @@ a_list_of_many = glob.glob(os.path.join(filepath, "eve", "*"))
 
 
 class TestTimeSeries:
+    @pytest.mark.filterwarnings('ignore:Unknown units')
     def test_factory_concatenate_same_source(self):
         # Test making a TimeSeries that is the concatenation of multiple files
         ts_from_list = sunpy.timeseries.TimeSeries(a_list_of_many, source='EVE', concatenate=True)
@@ -59,6 +64,7 @@ class TestTimeSeries:
         ts_from_list.columns == sunpy.timeseries.TimeSeries(
             a_list_of_many[0], source='EVE', concatenate=True).columns
 
+    @pytest.mark.filterwarnings('ignore:Unknown units')
     def test_factory_concatenate_different_source(self):
         # Test making a TimeSeries that is the concatenation of multiple files
         ts_from_list = sunpy.timeseries.TimeSeries(a_list_of_many, source='EVE', concatenate=True)
@@ -72,6 +78,7 @@ class TestTimeSeries:
         ts_from_list.columns == sunpy.timeseries.TimeSeries(
             a_list_of_many[0], source='EVE', concatenate=True).columns
 
+    @pytest.mark.filterwarnings('ignore:Unknown units')
     def test_factory_generate_list_of_ts(self):
         # Test making a list TimeSeries from multiple files
         ts_list = sunpy.timeseries.TimeSeries(a_list_of_many, source='EVE')
@@ -79,12 +86,19 @@ class TestTimeSeries:
         for ts in ts_list:
             assert isinstance(ts, sunpy.timeseries.sources.eve.EVESpWxTimeSeries)
 
+    @pytest.mark.filterwarnings('ignore:Unknown units')
     def test_factory_generate_from_glob(self):
         # Test making a TimeSeries from a glob
         ts_from_glob = sunpy.timeseries.TimeSeries(os.path.join(
             filepath, "eve", "*"), source='EVE', concatenate=True)
         assert isinstance(ts_from_glob, sunpy.timeseries.sources.eve.EVESpWxTimeSeries)
 
+    @pytest.mark.filterwarnings('ignore:Unknown units')
+    def test_factory_generate_from_pathlib(self):
+        # Test making a TimeSeries from a : pathlib.PosixPath
+        ts_from_pathlib = sunpy.timeseries.TimeSeries(Path(filepath).joinpath("gbm.fits"),
+                                                      source="GBMSummary")
+        assert isinstance(ts_from_pathlib, sunpy.timeseries.sources.fermi_gbm.GBMSummaryTimeSeries)
 # =============================================================================
 # Individual Implicit Source Tests
 # =============================================================================
@@ -109,6 +123,16 @@ class TestTimeSeries:
         ts_goes = sunpy.timeseries.TimeSeries(goes_filepath_com)
         assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
 
+    def test_implicit_new_goes15(self):
+        # Test a GOES TimeSeries
+        ts_goes = sunpy.timeseries.TimeSeries(new_goes15_filepath)
+        assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
+
+    def test_implicit_new_goes16(self):
+        # Test a GOES TimeSeries
+        ts_goes = sunpy.timeseries.TimeSeries(new_goes16_filepath)
+        assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
+
     def test_implicit_lyra(self):
         # Test a LYRA TimeSeries
         ts_lyra = sunpy.timeseries.TimeSeries(lyra_filepath)
@@ -159,6 +183,16 @@ class TestTimeSeries:
         ts_goes = sunpy.timeseries.TimeSeries(goes_filepath_com, source='XRS')
         assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
 
+    def test_new_goes15(self):
+        # Test a GOES TimeSeries
+        ts_goes = sunpy.timeseries.TimeSeries(new_goes15_filepath, source='XRS')
+        assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
+
+    def test_new_goes16(self):
+        # Test a GOES TimeSeries
+        ts_goes = sunpy.timeseries.TimeSeries(new_goes16_filepath, source='XRS')
+        assert isinstance(ts_goes, sunpy.timeseries.sources.goes.XRSTimeSeries)
+
     def test_lyra(self):
         # Test a LYRA TimeSeries
         ts_lyra = sunpy.timeseries.TimeSeries(lyra_filepath, source='LYRA')
@@ -176,9 +210,13 @@ class TestTimeSeries:
 
     def test_noaa_ind_txt(self):
         # Test a NOAAPredictIndices TimeSeries txt
-        ts_noaa_ind = sunpy.timeseries.TimeSeries(noaa_ind_txt_filepath, source='NOAAIndices')
+        with pytest.warns(SunpyDeprecationWarning):
+            ts_noaa_ind = sunpy.timeseries.TimeSeries(noaa_ind_txt_filepath, source='NOAAIndices')
         assert isinstance(ts_noaa_ind, sunpy.timeseries.sources.noaa.NOAAIndicesTimeSeries)
 
+    # The pre- data involves dates long in the future, so ignore an ERFA warning
+    # when parsing these dates.
+    @pytest.mark.filterwarnings('ignore:ERFA function.*dubious year')
     def test_noaa_pre_json(self):
         # Test a NOAAIndices TimeSeries json
         ts_noaa_pre = sunpy.timeseries.TimeSeries(
@@ -187,8 +225,9 @@ class TestTimeSeries:
 
     def test_noaa_pre_txt(self):
         # Test a NOAAIndices TimeSeries txt
-        ts_noaa_pre = sunpy.timeseries.TimeSeries(
-            noaa_pre_txt_filepath, source='NOAAPredictIndices')
+        with pytest.warns(SunpyDeprecationWarning):
+            ts_noaa_pre = sunpy.timeseries.TimeSeries(
+                noaa_pre_txt_filepath, source='NOAAPredictIndices')
         assert isinstance(ts_noaa_pre, sunpy.timeseries.sources.noaa.NOAAPredictIndicesTimeSeries)
 
 # ==============================================================================
@@ -215,14 +254,15 @@ class TestTimeSeries:
         base = parse_time(datetime.datetime.today())
         times = base - TimeDelta(np.arange(24*60)*u.minute)
         intensity = np.sin(np.arange(0, 12 * np.pi, ((12 * np.pi) / (24*60))))
+        units = {'intensity': u.W/u.m**2}
         data = DataFrame(intensity, index=times, columns=['intensity'])
 
         # Use a FITS file HDU using sunpy.io
         hdulist = sunpy.io.read_file(goes_filepath)
         meta = hdulist[0].header
         meta_md = MetaDict(OrderedDict(meta))
-        ts_hdu_meta = sunpy.timeseries.TimeSeries(data, meta)
-        ts_md_meta = sunpy.timeseries.TimeSeries(data, meta_md)
+        ts_hdu_meta = sunpy.timeseries.TimeSeries(data, meta, units)
+        ts_md_meta = sunpy.timeseries.TimeSeries(data, meta_md, units)
         assert ts_hdu_meta == ts_md_meta
 
         # Use a FITS file HDU using astropy.io
@@ -230,8 +270,8 @@ class TestTimeSeries:
         meta = hdulist[0].header
         hdulist.close()
         meta_md = MetaDict(sunpy.io.header.FileHeader(meta))
-        ts_hdu_meta = sunpy.timeseries.TimeSeries(data, meta)
-        ts_md_meta = sunpy.timeseries.TimeSeries(data, meta_md)
+        ts_hdu_meta = sunpy.timeseries.TimeSeries(data, meta, units)
+        ts_md_meta = sunpy.timeseries.TimeSeries(data, meta_md, units)
         assert ts_hdu_meta == ts_md_meta
 
     def test_generic_construction_basic(self):
@@ -269,7 +309,8 @@ class TestTimeSeries:
         meta = MetaDict({'key': 'value'})
 
         # Create TS omitting units input arguments
-        ts_1 = sunpy.timeseries.TimeSeries(data, meta)
+        with pytest.warns(SunpyUserWarning, match='Unknown units for intensity'):
+            ts_1 = sunpy.timeseries.TimeSeries(data, meta)
         assert isinstance(ts_1, sunpy.timeseries.timeseriesbase.GenericTimeSeries)
         assert ts_1.columns == ['intensity']
         assert ts_1.units == OrderedDict([('intensity', u.dimensionless_unscaled)])
@@ -316,7 +357,7 @@ class TestTimeSeries:
         data = DataFrame(intensity1, index=times, columns=['intensity'])
         data2 = DataFrame(intensity2, index=times, columns=['intensity2'])
         units = OrderedDict([('intensity', u.W/u.m**2)])
-        units2 = OrderedDict([('intensity', u.W/u.m**2)])
+        units2 = OrderedDict([('intensity2', u.W/u.m**2)])
         meta = MetaDict({'key': 'value'})
         meta2 = MetaDict({'key2': 'value2'})
 
@@ -346,7 +387,7 @@ class TestTimeSeries:
         data = DataFrame(intensity1, index=times, columns=['intensity'])
         data2 = DataFrame(intensity2, index=times, columns=['intensity2'])
         units = OrderedDict([('intensity', u.W/u.m**2)])
-        units2 = OrderedDict([('intensity', u.W/u.m**2)])
+        units2 = OrderedDict([('intensity2', u.W/u.m**2)])
         meta = MetaDict({'key': 'value'})
         meta2 = MetaDict({'key2': 'value2'})
 
